########################################
#### R packages needed for this code
#### descr{descr} 
########################################






####################################################
### Get the file   
####################################################

### If Windows user, copy the folder under the C: root directory
data <- read.table("C:/AERA 2013 MMWS workshop/AERA 2013 MMWS Data example/K_ELL_T2LEARN_exercise.dat", header = T, sep = "\t")

### If Mac user, copy the folder under Documents
# data <- read.table("/Users/bingyu/Documents/AERA 2013 MMWS workshop/AERA 2013 MMWS Data example/K_ELL_T2LEARN_exercise.dat", header = T, sep = "\t")

mmwexample <- data[,1:14]
str(mmwexample)

### Sample: 3091 Language minority children
### Outcome: T2LEARN
### Binary treatment: DMELLSRVC
### Multi-valued treatment: ELLSERVC (with four categories: pullout[1], inclass[2], biingual[3], and noservice[0])
### Pretreatment covariates for the exercise: 
###     HMLANG (with 3 category: missing, English, non-English)
###     RACE (with six categories: WHITE, BLACK, HISPANIC, ASIAN, NATIVE, OTHRACE)
###	CC1MSCALE, DMMSC1MSOR
###	CWKSESL, DMMSSES

### exclude cases with ELLSERVC = -9
mmwexample = data.frame(subset(mmwexample, ELLSERVC != -9))

### identify categorical variables
attach(mmwexample)
factor.list <- c("DMELLSRVC", "ELLSERVC", "HMLANG", "RACE", "DMMSC1MSOR", "DMMSSES")
for (i in 1:length(factor.list))
assign(paste(factor.list[i], ".f", sep = ""), as.factor(get(factor.list[i])))
mmwexample <- cbind(mmwexample, DMELLSRVC.f, ELLSERVC.f, HMLANG.f, RACE.f, DMMSC1MSOR.f, DMMSSES.f)
detach(mmwexample)
str(mmwexample)



################################################################
### Step 1: Estimate Propensity Scores for DMELLSRVC  
################################################################

### Propensity score model as a logistic regression
mmwexample.glm <- glm(DMELLSRVC.f ~ HMLANG.f+RACE.f+DMMSC1MSOR.f+DMMSSES.f+CC1MSCALE+CWKSESL, family = binomial, data = mmwexample)

### estimate propensity scores (on a logit scale)
LGP <- predict(mmwexample.glm, newdata = mmwexample, type = "link")



################################################################
### Step 2: Identify common support  
################################################################

### create common support indicator: SUPPORT4
attach(mmwexample)
SUPPORT4 <- ifelse(LGP < (min(tapply(LGP, mmwexample$DMELLSRVC, max)) + sd(LGP)*0.2), 
				ifelse(LGP > (max(tapply(LGP, mmwexample$DMELLSRVC, min)) - sd(LGP)*0.2), 1,0)
				,0)
					
table(mmwexample$DMELLSRVC, SUPPORT4)
detach(mmwexample)

### 3019 students with valid treatment information
### Among them, 6 students excluded from common support
### In the analytic sample of 3013 students 
###### 1316 had no service 
###### 1697 had ELL service 



################################################################
### Step 3: Conduct Propensity Score Stratification 
################################################################

### stratify the analytic sample into six strata based on each logit score
mmwexample <- subset(cbind(mmwexample, LGP, SUPPORT4), SUPPORT4 == 1)

n.strata = 9
attach(mmwexample)
LGP_STR <- cut(mmwexample$LGP, quantile(mmwexample$LGP, prob = seq(0, 1, 1/n.strata)), include.lowest = TRUE, labels = FALSE)
table_DMELLSRVC <- table(LGP_STR, mmwexample$DMELLSRVC)
table_DMELLSRVC


################################################################
### Step 4: Compute MMWS
################################################################

MMWS = NULL
pz1 = NULL
pz0 = NULL
nmz1 = NULL
nmz0 = NULL
total <- sum(mmwexample$SUPPORT4)

for (i in 1:total){
	pz1[i] <- sum(DMELLSRVC)/total
	pz0[i] <- (total - sum(DMELLSRVC))/total
		for (j in 1:n.strata) {
			if (LGP_STR[i] == j){
				nmz1[j] <- table_DMELLSRVC[j, 2]
				nmz0[j] <- table_DMELLSRVC[j, 1]	                   		
				MMWS[i] <- DMELLSRVC[i]*(pz1[i]/(nmz1[j]/(nmz1[j]+nmz0[j]))) + (1 - DMELLSRVC[i])*(pz0[i]/(nmz0[j]/(nmz1[j]+nmz0[j])))
									  }
				       }     
		          }

detach(mmwexample)

mmwexample <- cbind(mmwexample, LGP_STR, MMWS)
tapply(X=mmwexample$MMWS, INDEX=list(mmwexample$LGP_STR, mmwexample$DMELLSRVC), FUN=mean)

################################################################
### Step 5: Check Balance
################################################################



attach(mmwexample)

summary(aov(LGP ~ DMELLSRVC.f, data = mmwexample))
summary(aov(LGP ~ DMELLSRVC.f, data = mmwexample, weights = MMWS))

library(descr)
crosstab(mmwexample$HMLANG.f, mmwexample$DMELLSRVC.f, chisq = TRUE, plot = FALSE)$chisq
crosstab(mmwexample$HMLANG.f, mmwexample$DMELLSRVC.f, weight = MMWS, chisq = TRUE, plot = FALSE)$chisq
crosstab(mmwexample$DMMSC1MSOR.f, mmwexample$DMELLSRVC.f, chisq = TRUE, plot = FALSE)$chisq
crosstab(mmwexample$DMMSC1MSOR.f, mmwexample$DMELLSRVC.f, weight = MMWS, chisq = TRUE, plot = FALSE)$chisq
crosstab(mmwexample$DMMSSES.f, mmwexample$DMELLSRVC.f, chisq = TRUE, plot = FALSE)$chisq
crosstab(mmwexample$DMMSSES.f, mmwexample$DMELLSRVC.f, weight = MMWS, chisq = TRUE, plot = FALSE)$chisq
crosstab(mmwexample$RACE.f, mmwexample$DMELLSRVC.f, chisq = TRUE, plot = FALSE)$chisq
crosstab(mmwexample$RACE.f, mmwexample$DMELLSRVC.f, weight = MMWS, chisq = TRUE, plot = FALSE)$chisq
summary(aov(CC1MSCALE ~ DMELLSRVC.f, data = mmwexample))
summary(aov(CC1MSCALE ~ DMELLSRVC.f, data = mmwexample, weights = MMWS))
summary(aov(CWKSESL ~ DMELLSRVC.f, data = mmwexample))
summary(aov(CWKSESL ~ DMELLSRVC.f, data = mmwexample, weights = MMWS))

detach(mmwexample)



################################################################
### Step 6: Estimate Treatment Effects
################################################################

outcome.model <- lm(T2LEARN ~ DMELLSRVC, data = mmwexample)
summary(outcome.model)

outcome.aov <- aov(T2LEARN ~ DMELLSRVC.f, data = mmwexample)
print(model.tables(outcome.aov,"means"),digits=4)

outcome.model.mmws <- lm(T2LEARN ~ DMELLSRVC, data = mmwexample, weights = MMWS)
summary(outcome.model.mmws)

outcome.aov.mmws <- aov(T2LEARN ~ DMELLSRVC.f, data = mmwexample, weights = MMWS)
print(model.tables(outcome.aov.mmws,"means"),digits=4)




