########################################
#### R packages needed for this code
#### nnet{nnet} 
#### descr{descr} 
########################################






####################################################
### Get the file   
####################################################

### If Windows user, copy the folder under the C: root directory
data <- read.table("C:/AERA 2013 MMWS workshop/AERA 2013 MMWS Data example/K_ELL_T2LEARN_exercise.dat", header = T, sep = "\t")

### If Mac user, copy the folder under Documents
# data <- read.table("/Users/bingyu/Documents/AERA 2013 MMWS workshop/AERA 2013 MMWS Data example/K_ELL_T2LEARN_exercise.dat", header = T, sep = "\t")

mmwexample <- data[,1:14]
str(mmwexample)

### Sample: 3091 Language minority children
### Outcome: T2LEARN
### Binary treatment: DMELLSRVC
### Multi-valued treatment: ELLSERVC (with four categories: pullout[1], inclass[2], biingual[3], and noservice[0])
### Pretreatment covariates for the exercise: 
###     HMLANG (with 3 category: missing, English, non-English)
###     RACE (with six categories: WHITE, BLACK, HISPANIC, ASIAN, NATIVE, OTHRACE)
###	CC1MSCALE, DMMSC1MSOR
###	CWKSESL, DMMSSES

### exclude cases with ELLSERVC = -9
mmwexample = data.frame(subset(mmwexample, ELLSERVC != -9))

### identify categorical variables
attach(mmwexample)
factor.list <- c("DMELLSRVC", "ELLSERVC", "HMLANG", "RACE", "DMMSC1MSOR", "DMMSSES")
for (i in 1:length(factor.list))
assign(paste(factor.list[i], ".f", sep = ""), as.factor(get(factor.list[i])))
mmwexample <- cbind(mmwexample, DMELLSRVC.f, ELLSERVC.f, HMLANG.f, RACE.f, DMMSC1MSOR.f, DMMSSES.f)
detach(mmwexample)
str(mmwexample)



################################################################
### Step 1: Estimate Propensity Scores for ELLSERVC  
################################################################

### Multinomial logistic regression
library(nnet)
mmwexample.multinom <- multinom(ELLSERVC ~ HMLANG.f+RACE.f+DMMSC1MSOR.f+DMMSSES.f+CC1MSCALE+CWKSESL, data = mmwexample)

### estimate propensity scores
list1 <- c("NOSERVICE", "PULLOUT", "INCLASS", "BILINGUAL")
for (i in 1:length(list1))
assign(paste("PR_", list1[i], sep = ""), mmwexample.multinom$fitted.values[,i])

### Convert the propensity scores onto a logit scale
for (i in 1:length(list1))
assign(paste("LGP_", list1[i], sep = ""), log(get(paste("PR_", list1[i], sep = ""))/(1 - get(paste("PR_", list1[i], sep = "")))))



################################################################
### Step 2: Identify common support  
################################################################

### create common support indicator: SUPPORT4
attach(mmwexample)
SUPPORT4 <- ifelse(LGP_NOSERVICE < (min(tapply(LGP_NOSERVICE, mmwexample$ELLSERVC, max)) + sd(LGP_NOSERVICE)*0.2), 
				ifelse(LGP_NOSERVICE > (max(tapply(LGP_NOSERVICE, mmwexample$ELLSERVC, min)) - sd(LGP_NOSERVICE)*0.2),  
					ifelse(LGP_PULLOUT < (min(tapply(LGP_PULLOUT, mmwexample$ELLSERVC, max)) + sd(LGP_PULLOUT)*0.2), 
						ifelse(LGP_PULLOUT > (max(tapply(LGP_PULLOUT, mmwexample$ELLSERVC, min)) - sd(LGP_PULLOUT)*0.2),  
							ifelse(LGP_INCLASS < (min(tapply(LGP_INCLASS, mmwexample$ELLSERVC, max)) + sd(LGP_INCLASS)*0.2), 
								ifelse(LGP_INCLASS > (max(tapply(LGP_INCLASS, mmwexample$ELLSERVC, min)) - sd(LGP_INCLASS)*0.2), 
									ifelse(LGP_BILINGUAL < (min(tapply(LGP_BILINGUAL, mmwexample$ELLSERVC, max)) + sd(LGP_BILINGUAL)*0.2), 
										ifelse(LGP_BILINGUAL > (max(tapply(LGP_BILINGUAL, mmwexample$ELLSERVC, min)) - sd(LGP_BILINGUAL)*0.2), 1, 0)
										,0)
									 ,0)
								  ,0)
						       ,0)
							,0)
						 ,0)
					  ,0)
	
table(mmwexample$ELLSERVC, SUPPORT4)
detach(mmwexample)

### 3019 students with valid treatment information
### Among them, 160 students excluded from common support
### In the analytic sample of 2859 students 
###### 1186 had no service 
###### 422 had pull-out
###### 408 had in-class
###### 843 had bilingual services



################################################################
### Step 3: Conduct Propensity Score Stratification 
################################################################

### stratify the analytic sample into six strata based on each logit score

mmwexample <- subset(cbind(mmwexample, PR_NOSERVICE, PR_PULLOUT, PR_INCLASS, PR_BILINGUAL, 
			LGP_NOSERVICE, LGP_PULLOUT, LGP_INCLASS, LGP_BILINGUAL, SUPPORT4), SUPPORT4 == 1)

attach(mmwexample)

n.strata = 6

LGP_NOSERVICE_STR <- cut(mmwexample$LGP_NOSERVICE, quantile(mmwexample$LGP_NOSERVICE, prob = seq(0, 1, 1/n.strata)), 
			include.lowest = TRUE, labels = FALSE)
LGP_PULLOUT_STR <- cut(mmwexample$LGP_PULLOUT, quantile(mmwexample$LGP_PULLOUT, prob = seq(0, 1, 1/n.strata)), 
			include.lowest = TRUE, labels = FALSE)
LGP_INCLASS_STR <- cut(mmwexample$LGP_INCLASS, quantile(mmwexample$LGP_INCLASS, prob = seq(0, 1, 1/n.strata)), 
			include.lowest = TRUE, labels = FALSE)
LGP_BILINGUAL_STR <- cut(mmwexample$LGP_BILINGUAL, quantile(mmwexample$LGP_BILINGUAL, prob = seq(0, 1, 1/n.strata)), 
			include.lowest = TRUE, labels = FALSE)

table_NOSERVICE <- table(LGP_NOSERVICE_STR, mmwexample$NOSERVICE)
table_PULLOUT <- table(LGP_PULLOUT_STR, mmwexample$PULLOUT)
table_INCLASS <- table(LGP_INCLASS_STR, mmwexample$INCLASS)
table_BILINGUAL <- table(LGP_BILINGUAL_STR, mmwexample$BILINGUAL)

table_NOSERVICE
table_PULLOUT
table_INCLASS
table_BILINGUAL



################################################################
### Step 4: Compute MMWS
################################################################

MMWS = NULL
pz = NULL
nm = NULL
nmz = NULL
total <- sum(mmwexample$SUPPORT4)

list1 <- c("NOSERVICE", "PULLOUT", "INCLASS", "BILINGUAL")
list2 <- c("table_NOSERVICE", "table_PULLOUT", "table_INCLASS", "table_BILINGUAL")
list3 <- c("LGP_NOSERVICE_STR", "LGP_PULLOUT_STR", "LGP_INCLASS_STR", "LGP_BILINGUAL_STR")

for (i in 1:total){
	for (k in 1:4){
		if (get(list1[k])[i] == 1){
			pz[i] <- sum(get(list1[k]))/total
				for (j in 1:n.strata) {
				if (get(list3[k])[i] == j){
					nmz[j] <- get(list2[k])[j, 2]
					nm[j] <- get(list2[k])[j, 2] + get(list2[k])[j, 1]	                   		
					MMWS[i] <- pz[i]/(nmz[j]/nm[j])
							 			  }
				       	       }
					 			  }
		       	   }
		   		   }

detach(mmwexample)



################################################################
### Step 5: Check Balance
################################################################

mmwexample <- cbind(mmwexample, LGP_NOSERVICE_STR, LGP_PULLOUT_STR, LGP_INCLASS_STR, LGP_BILINGUAL_STR, MMWS)

attach(mmwexample)

summary(aov(LGP_NOSERVICE ~ ELLSERVC.f, data = mmwexample))
summary(aov(LGP_NOSERVICE ~ ELLSERVC.f, data = mmwexample, weights = MMWS))
summary(aov(LGP_PULLOUT ~ ELLSERVC.f, data = mmwexample))
summary(aov(LGP_PULLOUT ~ ELLSERVC.f, data = mmwexample, weights = MMWS))
summary(aov(LGP_INCLASS ~ ELLSERVC.f, data = mmwexample))
summary(aov(LGP_INCLASS ~ ELLSERVC.f, data = mmwexample, weights = MMWS))
summary(aov(LGP_BILINGUAL ~ ELLSERVC.f, data = mmwexample))
summary(aov(LGP_BILINGUAL ~ ELLSERVC.f, data = mmwexample, weights = MMWS))

library(descr)
crosstab(mmwexample$HMLANG.f, mmwexample$ELLSERVC.f, chisq = TRUE, plot = FALSE)$chisq
crosstab(mmwexample$HMLANG.f, mmwexample$ELLSERVC.f, weight = MMWS, chisq = TRUE, plot = FALSE)$chisq
crosstab(mmwexample$DMMSC1MSOR.f, mmwexample$ELLSERVC.f, chisq = TRUE, plot = FALSE)$chisq
crosstab(mmwexample$DMMSC1MSOR.f, mmwexample$ELLSERVC.f, weight = MMWS, chisq = TRUE, plot = FALSE)$chisq
crosstab(mmwexample$DMMSSES.f, mmwexample$ELLSERVC.f, chisq = TRUE, plot = FALSE)$chisq
crosstab(mmwexample$DMMSSES.f, mmwexample$ELLSERVC.f, weight = MMWS, chisq = TRUE, plot = FALSE)$chisq
crosstab(mmwexample$RACE.f, mmwexample$ELLSERVC.f, chisq = TRUE, plot = FALSE)$chisq
crosstab(mmwexample$RACE.f, mmwexample$ELLSERVC.f, weight = MMWS, chisq = TRUE, plot = FALSE)$chisq
summary(aov(CC1MSCALE ~ ELLSERVC.f, data = mmwexample))
summary(aov(CC1MSCALE ~ ELLSERVC.f, data = mmwexample, weights = MMWS))
summary(aov(CWKSESL ~ ELLSERVC.f, data = mmwexample))
summary(aov(CWKSESL ~ ELLSERVC.f, data = mmwexample, weights = MMWS))

detach(mmwexample)



################################################################
### Step 6: Estimate Treatment Effects
################################################################

outcome.model <- lm(T2LEARN ~ ELLSERVC.f, data = mmwexample)
summary(outcome.model)

outcome.model.mmws <- lm(T2LEARN ~ ELLSERVC.f, data = mmwexample, weights = MMWS)
summary(outcome.model.mmws)




