
GET
  FILE='C:\AERA 2013 MMWS workshop\AERA 2013 MMWS Data example\K_ELL_T2LEARN_exercise.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.

*** Sample: 3091 Language minority children
*** Outcome: T2LEARN
*** Binary treatment: DMELLSRVC
*** Multi-valued treatment: ELLSERVC (with four categories: pullout, inclass, biingual, and noservice)
*** Pretreatment covariates for the exercise: 
****** HMLANG (with 3 category: missing, English, non-English)
****** RACE (with six categories: WHITE, BLACK, HISPANIC, ASIAN, NATIVE, OTHRACE)
****** CC1MSCALE, DMMSC1MSOR
****** CWKSESL, DMMSSES


****************************************************************
*** Step 1: Estimate Propensity Scores for DMELLSRVC
****************************************************************

*** Binary logistic regression

LOGISTIC REGRESSION VARIABLES DMELLSRVC
  /METHOD=ENTER HMLANG RACE CC1MSCALE DMMSC1MSOR CWKSESL DMMSSES 
  /CONTRAST (HMLANG)=Indicator
  /CONTRAST (RACE)=Indicator
  /CONTRAST (DMMSC1MSOR)=Indicator
  /CONTRAST (DMMSSES)=Indicator
  /SAVE=PRED
  /CRITERIA=PIN(0.05) POUT(0.10) ITERATE(20) CUT(0.5).

RENAME VARIABLES PRE_1 = PR_DMELLSRVC.

*** Convert the propensity score onto a logit scale

COMPUTE LGP_DMELLSV = LN(PR_DMELLSRVC / (1 - PR_DMELLSRVC)).
VARIABLE LABELS LGP_DMELLSV "logit of propensity for the binary measure of ELL services".
EXECUTE.



****************************************************************
*** Step 2: Identify common support
****************************************************************

*** This part requires revision in programming!!!

MEANS TABLES=LGP_DMELLSV BY DMELLSRVC
  /CELLS MEAN STDDEV COUNT MIN MAX.

*** The maximum of the minima is -3.51
*** The minimum of the maxima is 4.23

*** 20% of a standard deviation is 1.1678 * .2 = 0.233566

*** The lower bound is -3.51 - 0.233566 = -3.743566
*** The upper bound is 4.23 + 0.233566 = 4.463566

NUMERIC SUPPORT2 (F8.0).
COMPUTE SUPPORT2 = 0.
DO IF LGP_DMELLSV > -3.743566 and  LGP_DMELLSV < 4.463566.
RECODE SUPPORT2 (0=1).
END IF.
EXECUTE.

VARIABLE LABELS SUPPORT2 'common support for evaluating binary ELL services'.
VALUE LABELS SUPPORT2 0 'not in common support' 1 'in common support'.

CROSSTABS
  /TABLES=DMELLSRVC BY SUPPORT2
  /FORMAT=AVALUE TABLES
  /CELLS=COUNT
  /COUNT ROUND CELL.

*** 3019 students with valid treatment information
*** Among them, 6 students are excluded from common support
*** In the analytic sample of 3013 students 
****** 1316 did not receive ELL services 
****** 1697 received ELL services

****************************************************************
*** Step 3: Conduct Propensity Score Stratification
****************************************************************

*** This part requires revision in programming!!!

*** stratify the analytic sample into nine strata 

USE ALL.
COMPUTE filter_$=(SUPPORT2 = 1 & DMELLSRVC >= 0).
VARIABLE LABELS filter_$ 'SUPPORT2 = 1 & DMELLSRVC >= 0 (FILTER)'.
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'.
FORMATS filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE.


RANK VARIABLES=LGP_DMELLSV (A)
  /NTILES(9)
  /PRINT=YES
  /TIES=MEAN.

RENAME VARIABLES NLGP_DME=NLGP_DME9.

CROSSTABS
  /TABLES=NLGP_DME9 BY DMELLSRVC
  /FORMAT=AVALUE TABLES
  /CELLS=COUNT
  /COUNT ROUND CELL.


****************************************************************
*** Step 4: Compute MMWS
****************************************************************

*** This part requires revision in programming!!!

NUMERIC MMWS_B (F8.2).

DO IF  DMELLSRVC = 0 & NLGP_DME9 = 1 .
COMPUTE MMWS_B = (1316 / 3013) / (277 / 334).
ELSE IF  DMELLSRVC = 0 & NLGP_DME9 = 2 .
COMPUTE MMWS_B = (1316 / 3013) / (250 / 335).
ELSE IF  DMELLSRVC = 0 & NLGP_DME9 = 3 .
COMPUTE MMWS_B = (1316 / 3013) / (194 / 335).
ELSE IF  DMELLSRVC = 0 & NLGP_DME9 = 4 .
COMPUTE MMWS_B = (1316 / 3013) / (175 / 335).
ELSE IF  DMELLSRVC = 0 & NLGP_DME9 = 5 .
COMPUTE MMWS_B = (1316 / 3013) / (128 / 335).
ELSE IF  DMELLSRVC = 0 & NLGP_DME9 = 6 .
COMPUTE MMWS_B = (1316 / 3013) / (110 / 351).
ELSE IF  DMELLSRVC = 0 & NLGP_DME9 = 7 .
COMPUTE MMWS_B = (1316 / 3013) / (78 / 318).
ELSE IF  DMELLSRVC = 0 & NLGP_DME9 = 8 .
COMPUTE MMWS_B = (1316 / 3013) / (56 / 336).
ELSE IF  DMELLSRVC = 0 & NLGP_DME9 = 9 .
COMPUTE MMWS_B = (1316 / 3013) / (48 / 334).

ELSE IF  DMELLSRVC = 1 & NLGP_DME9 = 1 .
COMPUTE MMWS_B = (1697 / 3013) / (57 / 335).
ELSE IF  DMELLSRVC = 1 & NLGP_DME9 = 2 .
COMPUTE MMWS_B = (1697 / 3013) / (85 / 335).
ELSE IF  DMELLSRVC = 1 & NLGP_DME9 = 3 .
COMPUTE MMWS_B = (1697 / 3013) / (141 / 335).
ELSE IF  DMELLSRVC = 1 & NLGP_DME9 = 4 .
COMPUTE MMWS_B = (1697 / 3013) / (160 / 335).
ELSE IF  DMELLSRVC = 1 & NLGP_DME9 = 5 .
COMPUTE MMWS_B = (1697 / 3013) / (207 / 335).
ELSE IF  DMELLSRVC = 1 & NLGP_DME9 = 6 .
COMPUTE MMWS_B = (1697 / 3013) / (241 / 335).
ELSE IF  DMELLSRVC = 1 & NLGP_DME9 = 7 .
COMPUTE MMWS_B = (1697 / 3013) / (240 / 335).
ELSE IF  DMELLSRVC = 1 & NLGP_DME9 = 8 .
COMPUTE MMWS_B = (1697 / 3013) / (280 / 335).
ELSE IF  DMELLSRVC = 1 & NLGP_DME9 = 9 .
COMPUTE MMWS_B = (1697 / 3013) / (286 / 335).
END IF.
EXECUTE.

VARIABLE LABELS MMWS_B 'MMWS for binary measure of ELL services'.

DESCRIPTIVES VARIABLES=MMWS_B
  /STATISTICS=MEAN STDDEV MIN MAX.

MEANS TABLES=MMWS_B BY NLGP_DME9 BY DMELLSRVC
  /CELLS MEAN COUNT.



****************************************************************
*** Step 5: Check Balance
****************************************************************

UNIANOVA LGP_DMELLSV BY DMELLSRVC
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(DMELLSRVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=DMELLSRVC.

UNIANOVA LGP_DMELLSV BY DMELLSRVC
  /REGWGT=MMWS_B
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(DMELLSRVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=DMELLSRVC.


*** HMLANG ***

CROSSTABS
  /TABLES=DMELLSRVC BY HMLANG
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT
  /COUNT ROUND CELL.

WEIGHT BY MMWS_B.
CROSSTABS
  /TABLES=DMELLSRVC BY HMLANG
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT
  /COUNT ROUND CELL.
WEIGHT OFF.

*** CC1MSCALE ***

 UNIANOVA CC1MSCALE BY DMELLSRVC
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(DMELLSRVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=DMELLSRVC.

UNIANOVA CC1MSCALE BY DMELLSRVC
  /REGWGT=MMWS_B
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(DMELLSRVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=DMELLSRVC.

*** DMMSC1MSOR ***

CROSSTABS
  /TABLES=DMELLSRVC BY DMMSC1MSOR
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT
  /COUNT ROUND CELL.

WEIGHT BY MMWS_B.
CROSSTABS
  /TABLES=DMELLSRVC BY DMMSC1MSOR
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT
  /COUNT ROUND CELL.
WEIGHT OFF.

*** CWKSESL ***

UNIANOVA CWKSESL BY DMELLSRVC
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(DMELLSRVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=DMELLSRVC.

UNIANOVA CWKSESL BY DMELLSRVC
  /REGWGT=MMWS_B
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(DMELLSRVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=DMELLSRVC.

*** DMMSSES ***

CROSSTABS
  /TABLES=DMELLSRVC BY DMMSSES
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT
  /COUNT ROUND CELL.

WEIGHT BY MMWS_B.
CROSSTABS
  /TABLES=DMELLSRVC BY DMMSSES
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT
  /COUNT ROUND CELL.
WEIGHT OFF.

*** RACE ***

CROSSTABS
  /TABLES=DMELLSRVC BY RACE
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT
  /COUNT ROUND CELL.

WEIGHT BY MMWS_B.
CROSSTABS
  /TABLES=DMELLSRVC BY RACE
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT
  /COUNT ROUND CELL.
WEIGHT OFF.


****************************************************************
*** Step 6: Estimate Treatment Effects
****************************************************************

UNIANOVA T2LEARN BY DMELLSRVC
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(DMELLSRVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=DMELLSRVC.

UNIANOVA T2LEARN BY DMELLSRVC
  /REGWGT=MMWS_B
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(DMELLSRVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=DMELLSRVC.

FILTER OFF.
USE ALL.
EXECUTE.




