
GET
  FILE='C:\AERA 2013 MMWS workshop\AERA 2013 MMWS Data example\K_ELL_T2LEARN_exercise.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.

*** Sample: 3091 Language minority children
*** Outcome: T2LEARN
*** Binary treatment: DMELLSRVC
*** Multi-valued treatment: ELLSERVC (with four categories: pullout, inclass, biingual, and noservice)
*** Pretreatment covariates for the exercise: 
****** HMLANG (with 3 category: missing, English, non-English)
****** RACE (with six categories: WHITE, BLACK, HISPANIC, ASIAN, NATIVE, OTHRACE)
****** CC1MSCALE, DMMSC1MSOR
****** CWKSESL, DMMSSES


****************************************************************
*** Step 1: Estimate Propensity Scores for ELLSERVC
****************************************************************

*** Multinomial logistic regression

NOMREG ELLSERVC (BASE=LAST ORDER=ASCENDING) BY HMLANG RACE DMMSC1MSOR DMMSSES WITH 
    CC1MSCALE CWKSESL
  /CRITERIA CIN(95) DELTA(0) MXITER(100) MXSTEP(5) CHKSEP(20) LCONVERGE(0) PCONVERGE(0.000001) 
    SINGULAR(0.00000001)
  /MODEL
  /STEPWISE=PIN(.05) POUT(0.1) MINEFFECT(0) RULE(SINGLE) ENTRYMETHOD(LR) REMOVALMETHOD(LR)
  /INTERCEPT=INCLUDE
  /PRINT=PARAMETER SUMMARY LRT CPS STEP MFI
  /SAVE ESTPROB.

RENAME VARIABLES EST1_1 = PR_NOSERVICE.
RENAME VARIABLES EST2_1 = PR_PULLOUT.
RENAME VARIABLES EST3_1 = PR_INCLASS.
RENAME VARIABLES EST4_1 = PR_BILINGUAL.

*** Convert the propensity scores onto a logit scale

COMPUTE LGP_NOSERVICE = LN(PR_NOSERVICE / (1 - PR_NOSERVICE)).
COMPUTE LGP_PULLOUT = LN(PR_PULLOUT / (1 - PR_PULLOUT)).
COMPUTE LGP_INCLASS = LN(PR_INCLASS / (1 - PR_INCLASS)).
COMPUTE LGP_BILINGUAL = LN(PR_BILINGUAL / (1 - PR_BILINGUAL)).
EXECUTE.

VARIABLE LABELS LGP_NOSERVICE "logit of propensity for no ELL services".
VARIABLE LABELS LGP_PULLOUT "logit of propensity for pullout services".
VARIABLE LABELS LGP_INCLASS "logit of propensity for in-class services".
VARIABLE LABELS LGP_BILINGUAL "logit of propensity for bilingual services".


****************************************************************
*** Step 2: Identify common support
****************************************************************

*** This part requires revision in programming!!!

*** LGP_NOSERVICE ***

MEANS TABLES=LGP_NOSERVICE BY ELLSERVC
  /CELLS MEAN STDDEV COUNT MIN MAX.

*** The maximum of the minima is -3.87
*** The minimum of the maxima is 2.22

*** 20% of a standard deviation is 1.16669 * .2 = 0.233338

*** The lower bound is -3.87 - 0.233338 = -4.103338
*** The upper bound is 2.22 + 0.233338 = 2.453338


*** LGP_PULLOUT ***

MEANS TABLES=LGP_PULLOUT BY ELLSERVC
  /CELLS MEAN STDDEV COUNT MIN MAX.

*** The maximum of the minima is -3.22
*** The minimum of the maxima is -0.42

*** 20% of a standard deviation is 0.70413 * .2 = 0.140826

*** The lower bound is -3.22 - 0.140826 = -3.360826
*** The upper bound is -0.42 + 0.140826 = -0.279174


*** LGP_INCLASS ***

MEANS TABLES=LGP_INCLASS BY ELLSERVC
  /CELLS MEAN STDDEV COUNT MIN MAX.

*** The maximum of the minima is -3.47
*** The minimum of the maxima is -0.78

*** 20% of a standard deviation is 0.64972 * .2 = 0.129944

*** The lower bound is -3.47 - 0.129944 = -3.599944
*** The upper bound is -0.78 + 0.129944 = -0.650056


*** LGP_BILINGUAL ***

MEANS TABLES=LGP_BILINGUAL BY ELLSERVC
  /CELLS MEAN STDDEV COUNT MIN MAX.

*** The maximum of the minima is -4.37
*** The minimum of the maxima is 0.37

*** 20% of a standard deviation is 1.20261 * .2 = 0.240522

*** The lower bound is -4.37 - 0.240522 = -4.610522
*** The upper bound is 0.37 + 0.240522 = 0.610522


*** Common Support for the Joint Distribution of the Four Propensity Scores ***

NUMERIC SUPPORT4 (F8.0).
COMPUTE SUPPORT4 = 0.
DO IF LGP_NOSERVICE > -3.360826 and  LGP_NOSERVICE < 2.453338
    and LGP_PULLOUT > -3.360826 and LGP_PULLOUT < -0.279174
    and LGP_INCLASS > -3.599944 and LGP_INCLASS  <  -0.650056
    and LGP_BILINGUAL > -4.610522 and LGP_BILINGUAL <  0.610522.
RECODE SUPPORT4 (0=1).
END IF.
EXECUTE.

VARIABLE LABELS SUPPORT4 'common support for evaluating 4-category ELL services'.
VALUE LABELS SUPPORT4 0 'not in common support' 1 'in common support'.

CROSSTABS
  /TABLES=ELLSERVC BY SUPPORT4
  /FORMAT=AVALUE TABLES
  /CELLS=COUNT
  /COUNT ROUND CELL.

*** 3019 students with valid treatment information
*** Among them, 160 students excluded from common support
*** In the analytic sample of 2859 students 
****** 1186 had no service 
****** 422 had pull-out
****** 408 had in-class
****** 843 had bilingual services

****************************************************************
*** Step 3: Conduct Propensity Score Stratification
****************************************************************

*** This part requires revision in programming!!!

*** stratify the analytic sample into six strata based on each logit score

USE ALL.
COMPUTE filter_$=(SUPPORT4 = 1 & ELLSERVC >= 0).
VARIABLE LABELS filter_$ 'SUPPORT4 = 1 & ELLSERVC >= 0 (FILTER)'.
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'.
FORMATS filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE.



RANK VARIABLES=LGP_NOSERVICE LGP_PULLOUT LGP_INCLASS LGP_BILINGUAL (A)
  /NTILES(6)
  /PRINT=YES
  /TIES=MEAN.

*** LGP_NOSERVICE ***

CROSSTABS
  /TABLES=NLGP_NOS BY NOSERVICE
  /FORMAT=AVALUE TABLES
  /CELLS=COUNT
  /COUNT ROUND CELL.

CROSSTABS
  /TABLES=NLGP_PUL  BY PULLOUT
  /FORMAT=AVALUE TABLES
  /CELLS=COUNT
  /COUNT ROUND CELL.

CROSSTABS
  /TABLES=NLGP_INC BY INCLASS
  /FORMAT=AVALUE TABLES
  /CELLS=COUNT
  /COUNT ROUND CELL.

CROSSTABS
  /TABLES=NLGP_BIL BY BILINGUAL
  /FORMAT=AVALUE TABLES
  /CELLS=COUNT
  /COUNT ROUND CELL.


****************************************************************
*** Step 4: Compute MMWS
****************************************************************

*** This part requires revision in programming!!!

NUMERIC MMWS (F8.2).

DO IF  NOSERVICE = 1 & NLGP_NOS = 1 .
COMPUTE MMWS = (1186 / 2859) / (67 / 476).
ELSE IF NOSERVICE = 1 & NLGP_NOS = 2 .
COMPUTE MMWS = (1186 / 2859) / (108 / 477).
ELSE IF NOSERVICE = 1 & NLGP_NOS = 3 .
COMPUTE MMWS = (1186 / 2859) / (151 / 476).
ELSE IF NOSERVICE = 1 & NLGP_NOS = 4 .
COMPUTE MMWS = (1186 / 2859) / (215 / 477).
ELSE IF NOSERVICE = 1 & NLGP_NOS = 5 .
COMPUTE MMWS = (1186 / 2859) / (279 / 477).
ELSE IF NOSERVICE = 1 & NLGP_NOS = 6 .
COMPUTE MMWS = (1186 / 2859) / (366 / 476).

ELSE IF  PULLOUT = 1 & NLGP_PUL = 1 .
COMPUTE MMWS = (422 / 2859) / (34 / 476).
ELSE IF PULLOUT = 1 & NLGP_PUL = 2 .
COMPUTE MMWS = (422 / 2859) / (43 / 477).
ELSE IF PULLOUT = 1 & NLGP_PUL = 3 .
COMPUTE MMWS = (422 / 2859) / (58 / 476).
ELSE IF PULLOUT = 1 & NLGP_PUL = 4.
COMPUTE MMWS = (422 / 2859) / (58 / 477).
ELSE IF PULLOUT = 1 & NLGP_PUL = 5 .
COMPUTE MMWS = (422 / 2859) / (81 / 477).
ELSE IF PULLOUT = 1 & NLGP_PUL = 6 .
COMPUTE MMWS = (422 / 2859) / (148 / 476).

ELSE IF  INCLASS = 1 & NLGP_INC = 1 .
COMPUTE MMWS = (408 / 2859) / (25 / 476).
ELSE IF  INCLASS = 1 & NLGP_INC = 2 .
COMPUTE MMWS = (408 / 2859) / (53 / 477).
ELSE IF  INCLASS = 1 & NLGP_INC = 3 .
COMPUTE MMWS = (408 / 2859) / (75 / 476).
ELSE IF  INCLASS = 1 & NLGP_INC = 4.
COMPUTE MMWS = (408 / 2859) / (87 / 477).
ELSE IF  INCLASS = 1 & NLGP_INC = 5 .
COMPUTE MMWS = (408 / 2859) / (75 / 477).
ELSE IF  INCLASS = 1 & NLGP_INC = 6 .
COMPUTE MMWS = (408 / 2859) / (93 / 476).

ELSE IF BILINGUAL = 1 & NLGP_BIL = 1 .
COMPUTE MMWS = (843 / 2859) / (36 / 476).
ELSE IF BILINGUAL = 1 & NLGP_BIL = 2 .
COMPUTE MMWS = (843 / 2859) / (64 / 477).
ELSE IF BILINGUAL = 1 & NLGP_BIL = 3 .
COMPUTE MMWS = (843 / 2859) / (98 / 476).
ELSE IF BILINGUAL = 1 & NLGP_BIL = 4 .
COMPUTE MMWS = (843 / 2859) / (155 / 477).
ELSE IF BILINGUAL = 1 & NLGP_BIL = 5 .
COMPUTE MMWS = (843 / 2859) / (225 / 477).
ELSE IF BILINGUAL = 1 & NLGP_BIL = 6 .
COMPUTE MMWS = (843 / 2859) / (265 / 476).
END IF.
EXECUTE.

DESCRIPTIVES VARIABLES=MMWS
  /STATISTICS=MEAN STDDEV MIN MAX.


****************************************************************
*** Step 5: Check Balance
****************************************************************

*** LGP_NOSERVICE ***

UNIANOVA LGP_NOSERVICE BY ELLSERVC
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(ELLSERVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=ELLSERVC.

UNIANOVA LGP_NOSERVICE BY ELLSERVC
  /REGWGT=MMWS
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(ELLSERVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=ELLSERVC.

*** LGP_PULLOUT ***

UNIANOVA LGP_PULLOUT BY ELLSERVC
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(ELLSERVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=ELLSERVC.

UNIANOVA LGP_PULLOUT BY ELLSERVC
  /REGWGT=MMWS
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(ELLSERVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=ELLSERVC.

*** LGP_INCLASS ***

UNIANOVA LGP_INCLASS BY ELLSERVC
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(ELLSERVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=ELLSERVC.

UNIANOVA LGP_INCLASS BY ELLSERVC
  /REGWGT=MMWS
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(ELLSERVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=ELLSERVC.

*** LGP_BILINGUAL ***

UNIANOVA LGP_BILINGUAL BY ELLSERVC
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(ELLSERVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=ELLSERVC.

UNIANOVA LGP_BILINGUAL BY ELLSERVC
  /REGWGT=MMWS
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(ELLSERVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=ELLSERVC.

*** HMLANG ***

CROSSTABS
  /TABLES=ELLSERVC BY HMLANG
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT
  /COUNT ROUND CELL.

WEIGHT BY MMWS.
CROSSTABS
  /TABLES=ELLSERVC BY HMLANG
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT
  /COUNT ROUND CELL.
WEIGHT OFF.

*** CC1MSCALE ***

 UNIANOVA CC1MSCALE BY ELLSERVC
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(ELLSERVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=ELLSERVC.

UNIANOVA CC1MSCALE BY ELLSERVC
  /REGWGT=MMWS
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(ELLSERVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=ELLSERVC.

*** DMMSC1MSOR ***

CROSSTABS
  /TABLES=ELLSERVC BY DMMSC1MSOR
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT
  /COUNT ROUND CELL.

WEIGHT BY MMWS.
CROSSTABS
  /TABLES=ELLSERVC BY DMMSC1MSOR
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT
  /COUNT ROUND CELL.
WEIGHT OFF.

*** CWKSESL ***

UNIANOVA CWKSESL BY ELLSERVC
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(ELLSERVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=ELLSERVC.

UNIANOVA CWKSESL BY ELLSERVC
  /REGWGT=MMWS
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(ELLSERVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=ELLSERVC.

*** DMMSSES ***

CROSSTABS
  /TABLES=ELLSERVC BY DMMSSES
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT
  /COUNT ROUND CELL.

WEIGHT BY MMWS.
CROSSTABS
  /TABLES=ELLSERVC BY DMMSSES
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT
  /COUNT ROUND CELL.
WEIGHT OFF.

*** RACE ***

CROSSTABS
  /TABLES=ELLSERVC BY RACE
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT
  /COUNT ROUND CELL.

WEIGHT BY MMWS.
CROSSTABS
  /TABLES=ELLSERVC BY RACE
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT
  /COUNT ROUND CELL.
WEIGHT OFF.


****************************************************************
*** Step 6: Estimate Treatment Effects
****************************************************************

UNIANOVA T2LEARN BY ELLSERVC
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(ELLSERVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=ELLSERVC.

UNIANOVA T2LEARN BY ELLSERVC
  /REGWGT=MMWS
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(ELLSERVC) 
  /CRITERIA=ALPHA(.05)
  /DESIGN=ELLSERVC.

FILTER OFF.
USE ALL.
EXECUTE.
