/*****************************************************************************/
/******** MMWS PROCEDURE FOR BINARY TREATMENT ********************/
/*****************************************************************************/

*** Sample: 3091 Language minority children
*** Outcome: t2learn
*** Binary treatment: dmellsrvc 
*** Multi-valued treatment: ellservc (with four categories: pullout, inclass, biingual, and noservice)
*** Pretreatment covariates for the exercise:
****** hmlang(with 3 category: missing, English, non-English)
****** race (with six categories: WHITE, BLACK, HISPANIC, ASIAN, NATIVE, OTHRACE)
****** cc1mscale, dmmsc1msor 
******  cwksesl, dmmsses  

u "C:\AERA 2013 MMWS workshop\AERA 2013 MMWS Data example\K_ELL_T2LEARN_exercise", clear
* Drop cases with no treatment information
drop if ellservc==-9

* Rename the pre-existing mmws variable 
rename mmws mmws_pre


** Dummy out the analysis covariates;
gen enghmlang = hmlang==1
gen m_hmlang = hmlang==0

gen othrace = race==0
gen white = race==1
gen black = race==2
gen asian = race==4
gen native = race==5


****************************************************************
*** Step 1: Estimate Propensity Scores for dmellsrvc 
**************************************************************** 

*** Logistic regression 
logit dmellsrvc i.hmlang i.race cc1mscale dmmsc1msor cwksesl dmmsses 

predict pr

gen lgp = logit(pr)

****************************************************************
*** Step 2: Identify common support
**************************************************************** 
egen stdlgp = sd(lgp)
gen sdslgp = 0.2*stdlgp

bysort dmellsrvc: egen minslgp=min(lgp)
egen minlgp=max(minslgp)

bysort dmellsrvc: egen maxslgp=max(lgp)
egen maxlgp=min(maxslgp)

*Create a variable that indicates if a student falls into the common support
gen supportlgp= (lgp>= (minlgp- sdslgp) & lgp<= maxlgp+ sdslgp)

ta supportlgp

** Keep only the students who are in the common support 
keep if supportlgp==1

*** 3019 students with valid treatment information
*** Among them, 6 students excluded from common support
*** In the analytic sample of 3013 students
****** 1316 had no service
****** 1697 received services

****************************************************************
*** Step 3: Conduct Propensity Score Stratification
**************************************************************** 
****************************************************************
*** Step 4: Compute MMWS
**************************************************************** 

*** Stratify the analytic sample into nine strata based on each logit score 
xtile strata=lgp, n(9)

ta strata dmellsrvc

**For the Treated Observations
** Find the proportion of obs. within a strata that actually receive the treatment
bysort strata: egen tmn=mean(dmellsrvc)
*** Take the inverse of that proportion
gen tiprws = 1/tmn
*** Find the overall proportion of treatment within the whole sample
egen tgprwws=mean(dmellsrvc) 
*** Calculate the weight for those observations that received the treatment
gen mmws = tiprws*tgprwws if dmellsrvc==1    


**For the Control Observations
*** Find the proportion of obs. within a strata in the control group
bysort strata: gen cmn=(1-tmn)
*** Take the inverse of that proportion
gen ciprws = 1/cmn
*** Find the overall proportion of control within the whole sample
gen cgprwws=(1-tgprwws) 
*** Calculate the weight for those observations in the control group
replace mmws = ciprws*cgprwws if dmellsrvc==0    

by strata dmellsrvc, sort: summarize mmws

****************************************************************
*** Step 5: Check Balance
****************************************************************

anova lgp dmellsrvc  
anova lgp dmellsrvc [aw=mmws] 

*** CHECK FOR BALANCE ON THE COVARIATES ***
global covars "cc1mscale cwksesl"
foreach var of varlist $covars {
anova `var' dmellsrvc  
anova `var' dmellsrvc [aw=mmws] 
}

global ccovars "othrace white black asian native enghmlang m_hmlang dmmsc1msor dmmsses"
foreach var of varlist $ccovars {
tab `var' dmellsrvc, chi2  
tab `var' dmellsrvc [aw=mmws], chi2 
}

****************************************************************
*** Step 6: Estimate Treatment Effects
****************************************************************

oneway t2learn dmellsrvc, tab 
oneway t2learn dmellsrvc [aw=mmws], tab

